document.addEventListener('DOMContentLoaded', () => {
  const codeEditor = document.getElementById('codeEditor');
  const output = document.getElementById('output');
  const runBtn = document.getElementById('runBtn');
  const clearBtn = document.getElementById('clearBtn');

  // Custom console.log implementation
  const customConsole = {
    log: (...args) => {
      const message = args.map(arg => 
        typeof arg === 'object' ? JSON.stringify(arg, null, 2) : String(arg)
      ).join(' ');
      output.innerHTML += `<div class="log-entry">${message}</div>`;
      output.scrollTop = output.scrollHeight;
    }
  };

  // Run code function
  const runCode = () => {
    output.innerHTML = ''; // Clear previous output
    const code = codeEditor.value;
    
    try {
      // Create a new Function with custom console
      const wrappedCode = `
        return (function() {
          const console = customConsole;
          ${code}
        })();
      `;
      new Function('customConsole', wrappedCode)(customConsole);
    } catch (error) {
      output.innerHTML += `<div class="log-entry error">${error.message}</div>`;
    }
  };

  // Event listeners
  runBtn.addEventListener('click', runCode);
  clearBtn.addEventListener('click', () => {
    output.innerHTML = '';
  });

  // Keyboard shortcuts
  codeEditor.addEventListener('keydown', (e) => {
    // Ctrl/Cmd + Enter to run code
    if ((e.ctrlKey || e.metaKey) && e.key === 'Enter') {
      e.preventDefault();
      runCode();
    }
    
    // Tab key support
    if (e.key === 'Tab') {
      e.preventDefault();
      const start = codeEditor.selectionStart;
      const end = codeEditor.selectionEnd;
      codeEditor.value = codeEditor.value.substring(0, start) + '  ' + 
                        codeEditor.value.substring(end);
      codeEditor.selectionStart = codeEditor.selectionEnd = start + 2;
    }
  });

  // Auto-save to localStorage
  const saveToLocalStorage = () => {
    localStorage.setItem('savedCode', codeEditor.value);
  };

  // Load saved code
  const savedCode = localStorage.getItem('savedCode');
  if (savedCode) {
    codeEditor.value = savedCode;
  }

  codeEditor.addEventListener('input', saveToLocalStorage);
});